@@ -83,7 +83,7 @@ class MyCobot(MyCobotCommandGenerator):
             if genre in [
                 ProtocolCode.IS_POWER_ON,
                 ProtocolCode.IS_CONTROLLER_CONNECTED,
-                ProtocolCode.IS_PAUSED,
+                ProtocolCode.IS_PAUSED,  # TODO have bug: return b''
                 ProtocolCode.IS_IN_POSITION,
                 ProtocolCode.IS_MOVING,
                 ProtocolCode.IS_SERVO_ENABLE,
@@ -95,6 +95,7 @@ class MyCobot(MyCobotCommandGenerator):
                 ProtocolCode.GET_SPEED,
                 ProtocolCode.GET_ENCODER,
                 ProtocolCode.GET_BASIC_INPUT,
+                ProtocolCode.GET_TOF_DISTANCE
             ]:
                 return self._process_single(res)
             elif genre in [ProtocolCode.GET_ANGLES]:
